# reddit2pdf

The majority of this repo is taken under GPL from bdfr-html found [here](https://github.com/aliparlakci/bulk-downloader-for-reddit) with modifications to work with my PKM system.

## Example usage

poetry run python -m reddit2pdf pdf --link https://www.reddit.com/r/homeautomation/comments/z4fn14/my_take_on_the_magsafe_home_assistant_wall/ --unclean -o ~/Desktop/test --move-html
